{#-
  Custom footer override matching ekgf-website
-#}
<footer class="ekgf-footer">
  <div class="md-grid ekgf-footer__inner">
    <div class="ekgf-footer__grid">
      {# About EKGF #}
      <div class="ekgf-footer__col">
        <h3 class="ekgf-footer__title">About EKGF</h3>
        <p class="ekgf-footer__text">
          Keep GenAI grounded in context for secure, high-quality
          decisions. EKGF is the Enterprise Knowledge Graph Forum
          at OMG.
        </p>
      </div>

      {# Documentation #}
      <div class="ekgf-footer__col">
        <h3 class="ekgf-footer__title">Documentation</h3>
        <ul class="ekgf-footer__list">
          <li><a href="https://ekgf.org/quadrants" class="ekgf-footer__link">The EKG Quadrants</a></li>
          <li><a href="https://method.ekgf.org" class="ekgf-footer__link">Method</a></li>
          <li><a href="https://catalog.ekgf.org/use-case/client-360/" class="ekgf-footer__link">Catalog</a></li>
          <li><a href="https://maturity.ekgf.org" class="ekgf-footer__link">Maturity Model</a></li>
          <li><a href="https://principles.ekgf.org/principle/#10-principles" class="ekgf-footer__link">Principles</a></li>
          <li><a href="https://ekgf.org/dprod" class="ekgf-footer__link">DPROD</a></li>
        </ul>
      </div>

      {# Resources #}
      <div class="ekgf-footer__col">
        <h3 class="ekgf-footer__title">Resources</h3>
        <ul class="ekgf-footer__list">
          <li><a href="https://ekgf.org/about" class="ekgf-footer__link">About Us</a></li>
          <li><a href="https://ekgf.org/membership" class="ekgf-footer__link">Membership</a></li>
          <li><a href="https://ekgf.org/team" class="ekgf-footer__link">Team</a></li>
          <li><a href="https://ekgf.org/resources" class="ekgf-footer__link">Resources</a></li>
          <li><a href="https://ekgf.org/contact" class="ekgf-footer__link">Contact</a></li>
          <li>
            {% for social in config.extra.social %}
              {% if "github" in social.icon %}
                <a href="{{ social.link }}" target="_blank" rel="noopener noreferrer" class="ekgf-footer__link ekgf-footer__link--icon">
                  <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-github" aria-hidden="true" style="width: 1rem; height: 1rem;">
                    <path d="M15 22v-4a4.8 4.8 0 0 0-1-3.5c3 0 6-2 6-5.5.08-1.25-.27-2.48-1-3.5.28-1.15.28-2.35 0-3.5 0 0-1 0-3 1.5-2.64-.5-5.36-.5-8 0C6 2 5 2 5 2c-.3 1.15-.3 2.35 0 3.5A5.403 5.403 0 0 0 4 9c0 3.5 3 5.5 6 5.5-.39.49-.68 1.05-.85 1.65-.17.6-.22 1.23-.15 1.85v4"></path>
                    <path d="M9 18c-4.51 2-5-2-7-2"></path>
                  </svg>
                  GitHub
                </a>
              {% endif %}
            {% endfor %}
          </li>
        </ul>
      </div>

      {# Connect #}
      <div class="ekgf-footer__col">
        <h3 class="ekgf-footer__title">Connect</h3>
        <div class="ekgf-footer__social">
          <a href="https://twitter.com/EKG_Foundation" target="_blank" rel="noopener noreferrer" class="ekgf-footer__social-link" aria-label="Twitter">
            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-twitter">
              <path d="M22 4s-.7 2.1-2 3.4c1.6 10-9.4 17.3-18 11.6 2.2.1 4.4-.6 6-2C3 15.5.5 9.6 3 5c2.2 2.6 5.6 4.1 9 4-.9-4.2 4-6.6 7-3.8 1.1 0 3-1.2 3-1.2z"/>
            </svg>
          </a>
          <a href="https://www.linkedin.com/company/EKGF" target="_blank" rel="noopener noreferrer" class="ekgf-footer__social-link" aria-label="LinkedIn">
            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-linkedin">
              <path d="M16 8a6 6 0 0 1 6 6v7h-4v-7a2 2 0 0 0-2-2 2 2 0 0 0-2 2v7h-4v-7a6 6 0 0 1 6-6z"/>
              <rect width="4" height="12" x="2" y="9"/>
              <circle cx="4" cy="4" r="2"/>
            </svg>
          </a>
          {% for social in config.extra.social %}
            {% if "github" in social.icon %}
              <a href="{{ social.link }}" target="_blank" rel="noopener noreferrer" class="ekgf-footer__social-link" aria-label="GitHub">
                <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-github">
                  <path d="M15 22v-4a4.8 4.8 0 0 0-1-3.5c3 0 6-2 6-5.5.08-1.25-.27-2.48-1-3.5.28-1.15.28-2.35 0-3.5 0 0-1 0-3 1.5-2.64-.5-5.36-.5-8 0C6 2 5 2 5 2c-.3 1.15-.3 2.35 0 3.5A5.403 5.403 0 0 0 4 9c0 3.5 3 5.5 6 5.5-.39.49-.68 1.05-.85 1.65-.17.6-.22 1.23-.15 1.85v4"/>
                  <path d="M9 18c-4.51 2-5-2-7-2"/>
                </svg>
              </a>
            {% endif %}
          {% endfor %}
        </div>
      </div>
    </div>

    <div class="ekgf-footer__bottom">
      <p class="ekgf-footer__license">
        <a href="http://creativecommons.org/licenses/by-sa/4.0/" target="_blank" rel="noopener noreferrer">
          <img src="https://img.shields.io/badge/License-CC%20BY--SA%204.0-lightgrey.svg" alt="License: CC BY-SA 4.0" />
        </a>
      </p>
      {% if config.copyright %}
        <p>{{ config.copyright }}</p>
      {% endif %}
      <p class="ekgf-footer__legal">
        An initiative of the
        <a href="https://ekgf.org" target="_blank" rel="noopener noreferrer">
          Enterprise Knowledge Graph Forum (EKGF)
        </a>, a Managed Community of the
        <a href="https://omg.org" target="_blank" rel="noopener noreferrer">
          Object Management Group (OMG)
        </a>
      </p>
    </div>
  </div>
</footer>
